<?php

namespace TDevAgency\Cms\Models\BaseModels;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Config;
use Kyslik\ColumnSortable\Sortable;
use Laravel\Scout\Searchable;
use Mcamara\LaravelLocalization\Facades\LaravelLocalization;

class Post extends Model
{
    use Sortable, Searchable;

    const POST_TYPE = 1;
    const CATEGORY_TYPE = 2;
    const PAGE_TYPE = 3;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'slug',
        'post_status',
        'sort_order',
        'id',
        'img',
        'post_type',
    ];

    public static function bind($id)
    {
        return self::findOrFail($id);
    }

    /**
     * @return HasMany
     */
    public function localizations(): HasMany
    {
        return $this->hasMany(PostLocalization::class);
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany
     */
    public function parentCategories()
    {
        return $this->belongsToMany(Post::class, 'post_connections', 'post_id', 'post_parent_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany
     */
    public function childrenCategories()
    {
        return $this->belongsToMany(Post::class, 'post_connections', 'post_parent_id', 'post_id')->with('parentCategories');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany
     */
    public function adminChildrenCategories()
    {
        return $this->belongsToMany(Post::class, 'post_connections', 'post_parent_id', 'post_id')->where('post_type', self::CATEGORY_TYPE);
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany
     */
    public function adminChildrenPosts()
    {
        return $this->belongsToMany(Post::class, 'post_connections', 'post_parent_id', 'post_id')->where('post_type', self::POST_TYPE);
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasOne
     */
    public function adminLocalization()
    {
        return $this->hasOne(PostLocalization::class)->where('lang', Config::get('app.fallback_locale'));
    }

    /**
     * @return HasMany
     */
    public function adminLocalizations()
    {
        return $this->hasMany(PostLocalization::class);
    }

    /**
     * @return HasOne
     */
    public function localization()
    {
        return $this->hasOne(PostLocalization::class)->where('lang', LaravelLocalization::getCurrentLocale());
    }

    public function toSearchableArray()
    {
        $array = $this->with('localization')->first()->toArray();
        unset($array['slug'], $array['localization']['lang'], $array['localization']['meta_title'], $array['localization']['meta_description']);
        return $array;
    }
}
