@extends('cms::admin.layouts.app')
@section('content')
@section('post.form')
    @csrf
    @php
        /**
 * @var \TDevAgency\Cms\Models\BaseModels\Post $post
 * @var $errors
 */
    @endphp

    <div v-show="errors.any()" style="display: none"
         class="alert alert-warning">@lang('cms:admin.validation_error')</div>
    <div class="row">
        <div class="col-12 col-md-8 col-xl-9">
            @if(count(LaravelLocalization::getSupportedLocales()) > 1)
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    @foreach(\Mcamara\LaravelLocalization\Facades\LaravelLocalization::getSupportedLocales() as $key => $lang)
                        <li class="nav-item">
                            <a class="nav-link {{!$loop->first? '': 'active'}}" data-toggle="tab"
                               href="#lang-{{$key}}" role="tab" aria-controls="{{$lang['name']}}"
                               aria-selected="{{$loop->first? 'true': 'false'}}">
                                <i class="{{flag_class($key)}}"></i>
                                {{$lang['name']}}</a>
                        </li>
                    @endforeach
                </ul>
            @endif
            <div class="tab-content">
                @foreach(\Mcamara\LaravelLocalization\Facades\LaravelLocalization::getSupportedLocales() as $key => $lang)
                    <div class="tab-pane {{!$loop->first? '': 'active'}}" id="lang-{{$key}}" role="tabpanel"
                         aria-labelledby="{{$lang['name']}}-tab">


                        <div class="card mt-3">
                            <h3 class="card-header">@lang('cms::admin.common_content')</h3>
                            <div class="card-body">
                                @component('cms::components.input')
                                    @slot('key', 'localizations.'.$key.'.title')
                                    @slot('placeholder', trans('cms::admin.title'))
                                    @slot('validate', 'required')
                                    @slot('value', old('localizations.'.$key.'.title', $post->localizations[$key]->title?? null))
                                @endcomponent

                                @component('cms::components.textarea')
                                    @slot('key', 'localizations.'.$key.'.short_description')
                                    @slot('validate', 'required')
                                    @slot('placeholder', trans('cms::admin.short_description'))
                                    @slot('value', old('localizations.'.$key.'.short_description', $post->localizations[$key]->short_description ?? null))
                                @endcomponent

                                @component('cms::components.wysywig')
                                    @slot('key', 'localizations.'.$key.'.description')
                                    @slot('validate', null)
                                    @slot('placeholder', trans('cms::admin.content'))
                                    @slot('value', old('localizations.'.$key.'.description', $post->localizations[$key]->description?? null))
                                @endcomponent
                            </div>
                        </div>
                        @if(!in_array('seo-block', config('cms.excluded_components')))
                            <div class="card">
                                <h3 class="card-header">@lang('cms::admin.seo_information')</h3>
                                <div class="card-body">

                                    @component('cms::components.input')
                                        @slot('key', 'localizations.'.$key.'.meta_title')
                                        @slot('placeholder', trans('cms::admin.meta_title'))
                                        @slot('validate', 'required')
                                        @slot('value', old('localizations.'.$key.'.meta_title', $post->localizations[$key]->meta_title?? null))
                                    @endcomponent

                                    @component('cms::components.textarea')
                                        @slot('key', 'localizations.'.$key.'.meta_description')
                                        @slot('validate', 'required')
                                        @slot('placeholder', trans('cms::admin.meta_description'))
                                        @slot('value', old('localizations.'.$key.'.meta_description', $post->localizations[$key]->meta_description ?? null))
                                    @endcomponent
                                </div>
                            </div>
                        @endif
                        {{-- Make foreach in the child component and specify lang key --}}
                        @yield('post.form.content.' . $key)
                    </div>

                @endforeach
            </div>


            @yield('post.form.content')
        </div>

        <div class="col-md-4 col-xl-3">
            <div class="card"
                 @if(count(LaravelLocalization::getSupportedLocales()) > 1) style="margin-top: 51px" @endif>
                <div class="card-body">
                    @if(!in_array('slug', config('cms.excluded_components')) && $post->slug !== null)
                        @component('cms::components.input')
                            @slot('key', 'slug')
                            @slot('placeholder', trans('cms::admin.slug'))
                            @slot('validate', 'required')
                            @slot('value', old('slug', $post->slug?? null))
                        @endcomponent
                    @endif

                    @component('cms::components.select2')
                        @slot('key', 'post_status')
                        @slot('placeholder', trans('cms::admin.status'))
                        @slot('options', [0=>trans('cms::admin.post_inactive'), 1=>trans('cms::admin.post_active')])
                        @slot('value', old('post_status', $post->post_status?? 0))
                    @endcomponent
                </div>
                <div class="card-footer text-right">
                    <button class="btn btn-success">@lang('cms::admin.save')</button>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3 class="card-title">@lang('cms::admin.image')</h3>
                    <div class="card-tools">
                        <button type="button" class="btn btn-tool" data-card-widget="collapse"
                                data-toggle="tooltip"
                                title="Collapse">
                            <i class="fas fa-minus"></i></button>
                    </div>
                </div>
                <div class="card-body">
                    @component('cms::components.image-picker')
                        @slot('name', 'img')
                        @slot('value', old('img', isset($post->img)? $post->img: null))
                    @endcomponent
                </div>
            </div>

            @isset($categories)
                @include('cms::admin.components.categories.categories-list', ['categories' => $categories])
            @endisset


            @yield('post.form.panel')
        </div>
    </div>
@show
@endsection
